@@ -9,8 +9,7 @@ from .taskloop import TaskLoop
 
 
 def get_free_ico(icos):
-    ico_list = [
-        key for key, v in icos.items() if not v]
+    ico_list = [key for key, v in icos.items() if not v]
     ico = None
     if ico_list:
         ico = ico_list.pop()
@@ -31,16 +30,8 @@ class TaskAssignator:
 
     """
 
-    def __init__(self,
-                 scheduler,
-                 queue_tasks,
-                 queue_answer,
-                 sta_assigned,
-                 dt_status,
-                 dt_group,
-                 enqueued,
-                 locker,
-                 *args, **kwargs):
+    def __init__(self, scheduler, queue_tasks, queue_answer, sta_assigned,
+                 dt_status, dt_group, enqueued, locker, *args, **kwargs):
         self.scheduler = scheduler
         self.queue_tasks = queue_tasks
         self.queue_ans = queue_answer
@@ -90,8 +81,10 @@ class TaskAssignator:
                             if len(scheduler.proc_tasks.get(ipt)) < \
                                scheduler.lnproc and \
                                ids not in sta_assigned:
-                                respuesta = {'station': ids,
-                                             'core': ipt, }
+                                respuesta = {
+                                    'station': ids,
+                                    'core': ipt,
+                                }
                                 if dt_status == 'GROUP':
                                     if scheduler.stations.get(ids).get(
                                             self.code_filter) in dt_group:
@@ -102,9 +95,12 @@ class TaskAssignator:
                                         self.scheduler.add_sta_assigned(
                                             ipt, ico, ids)
                                         self.locker.release()
-                                        ans = "TASK %s ADDED TO %s" % (
-                                            ids, ipt)
+                                        ans = "TASK %s ADDED TO %s" % (ids,
+                                                                       ipt)
                                         respuesta.update({'added': True})
+                                        element = scheduler.stations.get(
+                                            ids).get(self.code_filter)
+                                        dt_group.remove(element)
                                 elif dt_status == 'ALL':
                                     icos = scheduler.add_task(ids, ipt)
                                     ico = get_free_ico(icos)
