@@ -134,10 +134,12 @@ class TaskScheduler:
             if assigned_task:
                 if not self.sta_init.get(assigned_task):
                     args, kwargs = self.set_pst(assigned_task, args, kwargs)
-                result_args, result_kwargs = await shield(self.run_task(*args, **kwargs))
+                result_args, result_kwargs = await self.run_task(*args, **kwargs)
             else:
                 result_args, result_kwargs = args, kwargs
             return [ipt, ico, *result_args], result_kwargs
+        except asyncio.CancelledError as ce:
+            raise ce
         except Exception as e:
             if log:
                 log.exception(
@@ -165,10 +167,12 @@ class TaskScheduler:
                 if not self.sta_init.get(assigned_task):
                     args, kwargs = self.set_pst_n2s(
                         assigned_task, args, kwargs)
-                result_args, result_kwargs = await shield(self.n2s_coro(*args, **kwargs))
+                result_args, result_kwargs = await self.n2s_coro(*args, **kwargs)
             else:
                 result_args, result_kwargs = args, kwargs
             return [ipt, ico, *result_args], result_kwargs
+        except asyncio.CancelledError as ce:
+            raise ce
         except Exception as e:
             if log:
                 log.exception(
@@ -195,10 +199,12 @@ class TaskScheduler:
                 if not self.sta_init[assigned_task]:
                     args, kwargs = self.set_pst_s2n(
                         assigned_task, args, kwargs)
-                result_args, result_kwargs = await shield(self.s2n_coro(*args, **kwargs))
+                result_args, result_kwargs = await self.s2n_coro(*args, **kwargs)
             else:
                 result_args, result_kwargs = args, kwargs
             return [ipt, ico, *result_args], result_kwargs
+        except asyncio.CancelledError as ce:
+            raise ce
         except Exception as e:
             if log:
                 log.exception(
