@@ -190,12 +190,14 @@ class TaskLoop:
         :param fargs: the function to process input/output
         :param args: the unpacked list of extra arguments
         """
+        result_kwargs = {}
         if not task.cancelled():
             try:
                 result = task.result()
                 result_args, result_kwargs = result
                 loop = asyncio.get_event_loop()
-                if exception := result_kwargs.get("exception"):
+                exception = result_kwargs.get("exception")
+                if exception:
                     raise exception
                 if self.control == "STOP" or result_kwargs.get('stop'):
                     return "STOPPED"
@@ -224,7 +226,9 @@ class TaskLoop:
                       "kargs", kwargs)
                 raise ie
             except Exception as e:
-                log = result_kwargs.get('log')
+                log = None
+                if result_kwargs:
+                    log = result_kwargs.get('log')
                 msg = f"""TaskLoop. Result cancelled {task.cancelled()},
                     task {task},
                     coro {coro},
@@ -233,7 +237,6 @@ class TaskLoop:
                     msg_done = f"TaskLoop, exception, Task done {task.result()}"
                     if log:
                         log.exception(msg_done)
-                print(msg)
                 if log:
                     log.exception(msg)
                 print("TaskLoop. Excepcion en renew", e)
